/******************************************************************************/
/* Sistemas Integrados TEKNISA                                                */
/* Nome: 0012_CARSTPO_USR_IMPORTA_AF_COMPASSARGENTINA.sql                     */
/*                                                                            */
/* Descrio:                                                                 */
/* Procedure destinada a possibilitar que as AF's                             */
/* ajustadas/geradas pelo Portal sejam importadas                             */
/* no sistema da Teknisa e, para isso, a procedure verificar                 */
/* duas tabelas intermedirias entre os dois sistemas (tabelas pertencentes   */
/* ao banco de dados do sistema da Teknisa).                                  */
/* Criao:                                                                   */
/* 19/02/2013 - Marcelo Alexsandro                                            */
/******************************************************************************/

CREATE OR REPLACE
PROCEDURE USR_IMPORTA_AF IS
   V_SEQ_ANTERIOR  INTEGER;
   V_PRXAUTOFORNE  VARCHAR2(20);
   V_CDFILLANC     VARCHAR2(4);
   V_EMITENTE      VARCHAR2(4);
   V_CDEMPRESA     VARCHAR2(2);
   V_CDCOMPRADOR   VARCHAR2(12);
   V_COUNT         NUMBER;
   V_COUNT_LIMITE  NUMBER;
   V_IDTIPEMITGER  VARCHAR(1);
   V_RETURN        VARCHAR2(1);
   V_ERROR VARCHAR2(4000);
   V_VRFATOCONV    FLOAT;
   V_CDPRODESTO    VARCHAR2(10);
   V_QTDE_COMMIT   FLOAT := 0;
   V_TOTAL_COMMIT  FLOAT := 1000;
   V_EXISTE_AF     FLOAT;
BEGIN
   V_RETURN := USR_FUNC_BLOQUEIO('USR_INT_AUTOFORNE%USR_INT_ITEMAUTF', 'B');
   IF V_RETURN = 'S' THEN
      V_SEQ_ANTERIOR := NULL;
      FOR C_AUTOFORNE IN
       (SELECT
           A.NRSEQUENCIAL,
           A.CDFILDEST,
           A.CDFILLANC,
           A.NRAUTOFORN,
           A.CDEMPRESA,
           A.DTAUTOFORN,
           A.CDFORNECED,
           A.IDTPEXPITSOL,
           A.IDAFREVISADA,
           A.CDGERENTE,
           A.IDMOTIVOENVIO,
           A.IDAUTOFORNEX,
           A.IDTIPOLANCAF,
           A.CDOPERADOR,
           A.CDAFPORTAL,
           A.NRAFPORTAL
         FROM USR_INT_AUTOFORNE A
        WHERE A.DTIMPORTACAO IS NULL
          AND A.HRIMPORTACAO IS NULL
          AND A.DTGRAVACAO IS NOT NULL
          AND A.HRGRAVACAO IS NOT NULL
          AND A.IDORIGREGISTRO = 'P'
          AND EXISTS (SELECT 1
                        FROM FILGRUPFILI
                       WHERE FILGRUPFILI.CDGRUPFILI = '9999999999'
                         AND FILGRUPFILI.CDFILIAL = A.CDFILDEST)
        ORDER BY A.NRSEQUENCIAL, IDTPEXPITSOL DESC
        )
      LOOP
         V_EXISTE_AF  := 0;
         SELECT COUNT(1)
           INTO V_EXISTE_AF
           FROM AUTOFORNE
          WHERE AUTOFORNE.CDFILDEST  = C_AUTOFORNE.CDFILDEST
            AND AUTOFORNE.CDFILLANC  = C_AUTOFORNE.CDFILLANC
            AND AUTOFORNE.NRAUTOFORN = C_AUTOFORNE.NRAUTOFORN;
         IF (V_EXISTE_AF > 0) OR (C_AUTOFORNE.NRAUTOFORN IS NULL) THEN
            IF C_AUTOFORNE.IDTPEXPITSOL = '1' THEN
               UPDATE AUTOFORNE
                  SET IDBAIXAAF = NULL, USR_DTEXPORTA = NULL
                WHERE AUTOFORNE.CDFILDEST  = C_AUTOFORNE.CDFILDEST
                  AND AUTOFORNE.CDFILLANC  = C_AUTOFORNE.CDFILLANC
                  AND AUTOFORNE.NRAUTOFORN = C_AUTOFORNE.NRAUTOFORN;
               FOR C_ITEMAUTF IN
                  (SELECT
                      I.NRSEQUENCIAL,
                      I.NRSEQITEM,
                      I.CDFILDEST,
                      I.CDFILLANC,
                      I.NRAUTOFORN,
                      I.CDMARCA,
                      P.CDPRODUTO,
                      P.CDARVPROD,
                      I.DTPROGENTAF,
                      I.NMPRODUTO,
                      I.VRQTDEAF QTPROGENTAF,
                      I.VRPRECOUNIT VRPREUNIAF,
                      I.TXOBSITMAF,
                      I.IDTPEXPITSOL,
                      I.CDSOLPORTAL,
                      I.NRSOLPORTAL,
                      I.NRITEMSOLPORTAL,
                      I.CDAFPORTAL,
                      I.NRAFPORTAL,
                      I.NRITAFPORTAL
                    FROM USR_INT_ITEMAUTF I, PRODUTO P
                   WHERE I.DTIMPORTACAO IS NULL
                     AND I.HRIMPORTACAO IS NULL
                     AND I.DTGRAVACAO IS NOT NULL
                     AND I.HRGRAVACAO IS NOT NULL
                     AND I.IDORIGREGISTRO = 'P'
                     AND I.CDFILDEST = C_AUTOFORNE.CDFILDEST
                     AND I.NRSEQUENCIAL = C_AUTOFORNE.NRSEQUENCIAL
                     AND I.CDPRODUTO = P.CDARVPROD
                   ORDER BY I.NRSEQUENCIAL, I.CDPRODUTO, I.IDTPEXPITSOL DESC
                   )
               LOOP
                  IF C_ITEMAUTF.IDTPEXPITSOL = '1' THEN
                     IF (V_SEQ_ANTERIOR IS NULL) OR (V_SEQ_ANTERIOR <> C_ITEMAUTF.NRSEQUENCIAL) THEN
                        V_SEQ_ANTERIOR := C_ITEMAUTF.NRSEQUENCIAL;
                        IF (C_ITEMAUTF.CDFILDEST IS NOT NULL) AND (C_ITEMAUTF.CDFILLANC IS NOT NULL) AND (C_ITEMAUTF.NRAUTOFORN IS NOT NULL) THEN
                           V_PRXAUTOFORNE := C_ITEMAUTF.NRAUTOFORN;
                           V_CDFILLANC    := C_ITEMAUTF.CDFILLANC;
                           IF C_AUTOFORNE.CDOPERADOR IS NULL THEN
                              SELECT MAX(PRODCOMP.CDOPERADOR)
                                INTO V_CDCOMPRADOR
                                FROM PRODCOMP, PRODUTO PC
                               WHERE PRODCOMP.CDPRODUTO = PC.CDPRODUTO
                                 AND C_ITEMAUTF.CDARVPROD LIKE PC.CDARVPROD || '%';
                           ELSE
                              V_CDCOMPRADOR := C_AUTOFORNE.CDOPERADOR;
                           END IF;
                        ELSE
                           V_CDFILLANC  := C_ITEMAUTF.CDFILDEST;
                           NOVO_CODIGO('AUTOFORNE', V_PRXAUTOFORNE);
                           V_PRXAUTOFORNE := SUBSTR(V_PRXAUTOFORNE,11,10);
                           V_EMITENTE  := SUBSTR(EMITENTE(C_ITEMAUTF.CDFILDEST, C_ITEMAUTF.CDPRODUTO, C_AUTOFORNE.CDFORNECED),1,4);
                           V_CDEMPRESA := SUBSTR(V_EMITENTE, 3, 2);
                           V_IDTIPEMITGER := SUBSTR(V_EMITENTE, 1, 1);

                           IF C_AUTOFORNE.CDOPERADOR IS NULL THEN
                              SELECT MAX(PRODCOMP.CDOPERADOR)
                                INTO V_CDCOMPRADOR
                                FROM PRODCOMP, PRODUTO PC
                               WHERE PRODCOMP.CDPRODUTO = PC.CDPRODUTO
                                 AND C_ITEMAUTF.CDARVPROD LIKE PC.CDARVPROD || '%';
                           ELSE
                              V_CDCOMPRADOR := C_AUTOFORNE.CDOPERADOR;
                           END IF;

                           INSERT INTO AUTOFORNE
                              (CDFILDEST, CDFILLANC, NRAUTOFORN, CDOPERADOR,
                               CDFORNECED, DTAUTOFORN, IDTIPOEMITAF, CDEMPRESA,
                               IDBAIXAAF, USR_AFIMPORTADA, USR_IDAFREVISADA,
                               CDGERENTE, IDAUTOFORNEX, IDTIPOLANCAF,
                               USR_CDAFPORTAL, USR_NRAFPORTAL, IDAUXIMPPORTAL, USR_DTEXPORTA)
                           VALUES
                              (C_ITEMAUTF.CDFILDEST, V_CDFILLANC, V_PRXAUTOFORNE, V_CDCOMPRADOR,
                               C_AUTOFORNE.CDFORNECED,TRUNC(SYSDATE), V_IDTIPEMITGER, V_CDEMPRESA,
                               NULL, 'S', C_AUTOFORNE.IDAFREVISADA,
                               C_AUTOFORNE.CDGERENTE, C_AUTOFORNE.IDAUTOFORNEX, C_AUTOFORNE.IDTIPOLANCAF,
                               C_AUTOFORNE.CDAFPORTAL, C_AUTOFORNE.NRAFPORTAL, 'S', NULL);
                        END IF;
                        UPDATE AUTOFORNE
                           SET USR_CDAFPORTAL   = C_AUTOFORNE.CDAFPORTAL,
                               USR_NRAFPORTAL   = C_AUTOFORNE.NRAFPORTAL,
                               USR_AFIMPORTADA  = 'S',
                               IDAUXIMPPORTAL   = 'S',
                               USR_IDAFREVISADA = C_AUTOFORNE.IDAFREVISADA,
                               USR_DTEXPORTA    = NULL
                         WHERE CDFILDEST = C_ITEMAUTF.CDFILDEST
                           AND CDFILLANC = V_CDFILLANC
                           AND NRAUTOFORN = V_PRXAUTOFORNE;
                     END IF;

                     BEGIN
                        INSERT INTO ITEMAUTF
                          (CDFILDEST, CDFILLANC, NRAUTOFORN,
                           CDMARCA, CDPRODUTO,  DTPROGENTAF,
                           VRPREUNIAF, QTPROGENTAF, NRPARCITMAF, IDBAIXITMAF,
                           USR_CDSOLPORTAL, USR_NRSOLPORTAL, USR_NRITEMSOLPORTAL,
                           USR_CDAFPORTAL, USR_NRAFPORTAL, USR_NRITAFPORTAL)
                        VALUES
                          (C_ITEMAUTF.CDFILDEST, V_CDFILLANC, V_PRXAUTOFORNE,
                           C_ITEMAUTF.CDMARCA, C_ITEMAUTF.CDPRODUTO, C_ITEMAUTF.DTPROGENTAF,
                           C_ITEMAUTF.VRPREUNIAF, C_ITEMAUTF.QTPROGENTAF, '00', NULL,
                           C_ITEMAUTF.CDSOLPORTAL, C_ITEMAUTF.NRSOLPORTAL, C_ITEMAUTF.NRITEMSOLPORTAL,
                           C_ITEMAUTF.CDAFPORTAL, C_ITEMAUTF.NRAFPORTAL, C_ITEMAUTF.NRITAFPORTAL
                           );
                     EXCEPTION
                        WHEN DUP_VAL_ON_INDEX THEN BEGIN
                           UPDATE ITEMAUTF
                              SET VRPREUNIAF  = C_ITEMAUTF.VRPREUNIAF,
                                  QTPROGENTAF = C_ITEMAUTF.QTPROGENTAF,
                                  TXOBSITMAF  = C_ITEMAUTF.TXOBSITMAF,
                                  IDBAIXITMAF = DECODE(IDBAIXITMAF, '3', NULL, IDBAIXITMAF),
                                  USR_CDSOLPORTAL      = C_ITEMAUTF.CDSOLPORTAL,
                                  USR_NRSOLPORTAL      = C_ITEMAUTF.NRSOLPORTAL,
                                  USR_NRITEMSOLPORTAL  = C_ITEMAUTF.NRITEMSOLPORTAL,
                                  USR_CDAFPORTAL       = C_ITEMAUTF.CDAFPORTAL,
                                  USR_NRAFPORTAL       = C_ITEMAUTF.NRAFPORTAL,
                                  USR_NRITAFPORTAL     = C_ITEMAUTF.NRITAFPORTAL
                            WHERE CDFILDEST   = C_ITEMAUTF.CDFILDEST
                              AND CDFILLANC   = V_CDFILLANC
                              AND NRAUTOFORN  = V_PRXAUTOFORNE
                              AND CDMARCA     = C_ITEMAUTF.CDMARCA
                              AND CDPRODUTO   = C_ITEMAUTF.CDPRODUTO
                              AND DTPROGENTAF = C_ITEMAUTF.DTPROGENTAF;
                        END;
                     END;

                     UPDATE ITEMSOLI
                        SET QTSOLIPROD = C_ITEMAUTF.QTPROGENTAF
                      WHERE USR_CDORIGEMPORTAL = C_ITEMAUTF.CDSOLPORTAL
                        AND USR_NRORIGEMPORTAL = C_ITEMAUTF.NRSOLPORTAL
                        AND USR_NRITEMPORTAL   = C_ITEMAUTF.NRITEMSOLPORTAL
                        AND CDFILSOLI          = C_ITEMAUTF.CDFILDEST
                        AND CDPRODUTO          = C_ITEMAUTF.CDPRODUTO;

                     IF (NOT(SQL%ROWCOUNT > 0)) THEN
                        BEGIN
                           SELECT VRFATOCONV, CDPRODESTO
                             INTO V_VRFATOCONV, V_CDPRODESTO
                             FROM PRODUTO
                            WHERE PRODUTO.CDPRODUTO = C_ITEMAUTF.CDPRODUTO;
                        EXCEPTION
                           WHEN NO_DATA_FOUND THEN BEGIN
                              V_VRFATOCONV := 1;
                              V_CDPRODESTO := NULL;
                           END;
                        END;

                        UPDATE ITEMSOLI
                           SET QTSOLIPROD         = (C_ITEMAUTF.QTPROGENTAF * V_VRFATOCONV)/(SELECT NVL(PRODUTO.VRFATOCONV, 1) FROM PRODUTO WHERE PRODUTO.CDPRODUTO = ITEMSOLI.CDPRODUTO)
                         WHERE USR_CDORIGEMPORTAL = C_ITEMAUTF.CDSOLPORTAL
                           AND USR_NRORIGEMPORTAL = C_ITEMAUTF.NRSOLPORTAL
                           AND USR_NRITEMPORTAL   = C_ITEMAUTF.NRITEMSOLPORTAL
                           AND CDFILSOLI          = C_ITEMAUTF.CDFILDEST
                           AND EXISTS (SELECT 1
                                         FROM PRODUTO P
                                        WHERE P.CDPRODUTO  = ITEMSOLI.CDPRODUTO
                                          AND P.CDPRODESTO = V_CDPRODESTO);
                     END IF;

                     UPDATE USR_INT_ITEMAUTF
                        SET DTIMPORTACAO = TO_DATE(TRUNC(SYSDATE)),
                            HRIMPORTACAO = TO_CHAR(SYSDATE, 'HH24MI')
                      WHERE NRSEQUENCIAL = C_ITEMAUTF.NRSEQUENCIAL
                        AND NRSEQITEM = C_ITEMAUTF.NRSEQITEM;
                  ELSE
                     IF C_ITEMAUTF.IDTPEXPITSOL = '2' THEN
                        UPDATE ITEMAUTF
                           SET IDBAIXITMAF = '3'
                         WHERE ITEMAUTF.CDFILDEST   = C_ITEMAUTF.CDFILDEST
                           AND ITEMAUTF.CDFILLANC   = C_ITEMAUTF.CDFILLANC
                           AND ITEMAUTF.NRAUTOFORN  = C_ITEMAUTF.NRAUTOFORN
                           AND ITEMAUTF.CDPRODUTO   = C_ITEMAUTF.CDPRODUTO
                           AND ITEMAUTF.DTPROGENTAF = C_ITEMAUTF.DTPROGENTAF;

    /*                    SELECT COUNT(1)
                          INTO V_COUNT
                          FROM ITEMAUTF
                         WHERE ITEMAUTF.CDFILDEST  = C_ITEMAUTF.CDFILDEST
                           AND ITEMAUTF.CDFILLANC  = C_ITEMAUTF.CDFILLANC
                           AND ITEMAUTF.NRAUTOFORN = C_ITEMAUTF.NRAUTOFORN;

                        IF V_COUNT = 0 THEN
                           DELETE FROM AUTOFORNE
                            WHERE AUTOFORNE.CDFILDEST  = C_ITEMAUTF.CDFILDEST
                              AND AUTOFORNE.CDFILLANC  = C_ITEMAUTF.CDFILLANC
                              AND AUTOFORNE.NRAUTOFORN = C_ITEMAUTF.NRAUTOFORN;
                        END IF;
    */

                        UPDATE USR_INT_ITEMAUTF
                           SET DTIMPORTACAO = TO_DATE(SYSDATE),
                               HRIMPORTACAO = TO_CHAR(SYSDATE, 'HH24MI')
                        WHERE NRSEQUENCIAL = C_ITEMAUTF.NRSEQUENCIAL
                          AND NRSEQITEM    = C_ITEMAUTF.NRSEQITEM;
                     END IF;
                  END IF;
               END LOOP;
               FECHAMENTO_AF(C_AUTOFORNE.CDFILDEST, NVL(C_AUTOFORNE.CDFILLANC, V_CDFILLANC), NVL(C_AUTOFORNE.NRAUTOFORN, V_PRXAUTOFORNE));
               V_COUNT_LIMITE := 0;

               IF NVL(C_AUTOFORNE.IDAFREVISADA, 'N') = 'N' THEN
                 SELECT COUNT(1)
                   INTO V_COUNT_LIMITE
                 FROM AUTOFORNE, COMPRADOR
                 WHERE AUTOFORNE.CDFILDEST  = C_AUTOFORNE.CDFILDEST
                   AND AUTOFORNE.CDFILLANC  = NVL(C_AUTOFORNE.CDFILLANC, V_CDFILLANC)
                   AND AUTOFORNE.NRAUTOFORN = NVL(C_AUTOFORNE.NRAUTOFORN, V_PRXAUTOFORNE)
                   AND AUTOFORNE.CDOPERADOR = COMPRADOR.CDOPERADOR
                   AND AUTOFORNE.VRTOTALAF > COMPRADOR.VRLIMAFCOMP;

                 IF V_COUNT_LIMITE > 0 THEN
                    UPDATE AUTOFORNE
                       SET IDAFFORALIM = 'S', IDAUXIMPPORTAL = 'S', USR_DTEXPORTA = NULL
                     WHERE AUTOFORNE.CDFILDEST  = C_AUTOFORNE.CDFILDEST
                       AND AUTOFORNE.CDFILLANC  = NVL(C_AUTOFORNE.CDFILLANC, V_CDFILLANC)
                       AND AUTOFORNE.NRAUTOFORN = NVL(C_AUTOFORNE.NRAUTOFORN, V_PRXAUTOFORNE);
                 ELSE
                    V_COUNT_LIMITE := 0;
                    SELECT COUNT(1)
                      INTO V_COUNT_LIMITE
                    FROM COMPRADOR, AUTOFORNE,
                      (SELECT SUM(VRTOTALAF) AS SOMAAF
                       FROM AUTOFORNE
                       WHERE  AUTOFORNE.DTMESAUTOFOR =
                                     (SELECT DTMESAUTOFOR
                                      FROM AUTOFORNE
                                      WHERE CDFILDEST  = C_AUTOFORNE.CDFILDEST
                                        AND CDFILLANC  = NVL(C_AUTOFORNE.CDFILLANC, V_CDFILLANC)
                                        AND NRAUTOFORN = NVL(C_AUTOFORNE.NRAUTOFORN, V_PRXAUTOFORNE)) AND
                       CDFILDEST  = C_AUTOFORNE.CDFILDEST AND
                       CDOPERADOR = V_CDCOMPRADOR
                    ) SUMVRTOTALAF
                    WHERE (AUTOFORNE.CDFILDEST = C_AUTOFORNE.CDFILDEST) AND
                          (AUTOFORNE.CDFILLANC = NVL(C_AUTOFORNE.CDFILLANC, V_CDFILLANC)) AND
                          (AUTOFORNE.NRAUTOFORN= NVL(C_AUTOFORNE.NRAUTOFORN, V_PRXAUTOFORNE)) AND
                          (AUTOFORNE.CDOPERADOR = COMPRADOR.CDOPERADOR) AND
                          SOMAAF > COMPRADOR.VRLIMAFMES;
                    IF V_COUNT_LIMITE > 0 THEN
                       UPDATE AUTOFORNE
                          SET IDAFFORALIM = 'S', IDAUXIMPPORTAL = 'S', USR_DTEXPORTA = NULL
                        WHERE AUTOFORNE.CDFILDEST  = C_AUTOFORNE.CDFILDEST
                          AND AUTOFORNE.CDFILLANC  = NVL(C_AUTOFORNE.CDFILLANC, V_CDFILLANC)
                          AND AUTOFORNE.NRAUTOFORN = NVL(C_AUTOFORNE.NRAUTOFORN, V_PRXAUTOFORNE);
                    ELSE
                       V_COUNT_LIMITE := 0;
                       FOR C_ITEM_LIMITE IN
                          (SELECT DISTINCT CDPRODUTO
                             FROM ITEMAUTF
                            WHERE ITEMAUTF.CDFILDEST  = C_AUTOFORNE.CDFILDEST
                              AND ITEMAUTF.CDFILLANC  = NVL(C_AUTOFORNE.CDFILLANC, V_CDFILLANC)
                              AND ITEMAUTF.NRAUTOFORN = NVL(C_AUTOFORNE.NRAUTOFORN, V_PRXAUTOFORNE))
                       LOOP
                          SELECT COUNT(1)
                            INTO V_COUNT_LIMITE
                          FROM LIMPRODAF, AUTOFORNE, PRODUTO, PRODUTO P,
                             (SELECT
                                PRODUTO,
                                SUM(VRPRODUTO)  -
                                NVL(SUM(VRDESCONTO), 0) +
                                NVL(SUM(VRIMPOSTO), 0) AS SOMAAF
                              FROM
                                (
                                SELECT
                                   SUM(ITEMAUTF.QTPROGENTAF * ITEMAUTF.VRPREUNIAF) AS VRPRODUTO,
                                   SUM((ITEMAUTF.QTPROGENTAF * ITEMAUTF.VRPREUNIAF *
                                        ITEMAUTF.VRPERDESAF) / 100)                AS VRDESCONTO,
                                   SUM(0) AS VRIMPOSTO,
                                   ITEMAUTF.CDPRODUTO AS PRODUTO
                                FROM
                                   ITEMAUTF
                                WHERE
                                   ITEMAUTF.CDFILDEST   = C_AUTOFORNE.CDFILDEST  AND
                                   ITEMAUTF.CDFILLANC   = NVL(C_AUTOFORNE.CDFILLANC, V_CDFILLANC) AND
                                   ITEMAUTF.NRAUTOFORN  = NVL(C_AUTOFORNE.NRAUTOFORN, V_PRXAUTOFORNE) AND
                                   ITEMAUTF.CDPRODUTO   = C_ITEM_LIMITE.CDPRODUTO
                                GROUP BY ITEMAUTF.CDPRODUTO

                                UNION

                                SELECT
                                   SUM(0) AS VRPRODUTO,
                                   SUM(0) AS VRDESCONTO,
                                   SUM(IMPITMAF.VRADIMPAF) AS VRIMPOSTO,
                                   ITEMAUTF.CDPRODUTO AS PRODUTO
                                FROM
                                   IMPITMAF,
                                   ITEMAUTF
                                WHERE
                                   IMPITMAF.CDFILDEST   = C_AUTOFORNE.CDFILDEST  AND
                                   IMPITMAF.CDFILLANC   = NVL(C_AUTOFORNE.CDFILLANC, V_CDFILLANC) AND
                                   IMPITMAF.NRAUTOFORN  = NVL(C_AUTOFORNE.NRAUTOFORN, V_PRXAUTOFORNE) AND
                                   IMPITMAF.CDFILDEST   = ITEMAUTF.CDFILDEST   AND
                                   IMPITMAF.CDFILLANC   = ITEMAUTF.CDFILLANC   AND
                                   IMPITMAF.NRAUTOFORN  = ITEMAUTF.NRAUTOFORN  AND
                                   IMPITMAF.CDPRODUTO   = ITEMAUTF.CDPRODUTO   AND
                                   IMPITMAF.CDMARCA     = ITEMAUTF.CDMARCA     AND
                                   IMPITMAF.DTPROGENTAF = ITEMAUTF.DTPROGENTAF AND
                                   ITEMAUTF.CDPRODUTO   = C_ITEM_LIMITE.CDPRODUTO
                                GROUP BY ITEMAUTF.CDPRODUTO

                                )
                                GROUP BY PRODUTO)

                          WHERE PRODUTO.CDPRODUTO = PRODUTO AND
                                (AUTOFORNE.CDFILDEST = C_AUTOFORNE.CDFILDEST) AND
                                (AUTOFORNE.CDFILLANC = NVL(C_AUTOFORNE.CDFILLANC, V_CDFILLANC)) AND
                                (AUTOFORNE.NRAUTOFORN= NVL(C_AUTOFORNE.NRAUTOFORN, V_PRXAUTOFORNE)) AND
                                AUTOFORNE.CDOPERADOR = LIMPRODAF.CDOPERADOR AND
                                P.CDPRODUTO = LIMPRODAF.CDPRODUTO AND
                                P.CDARVPROD =
                                                (SELECT MAX(PR.CDARVPROD)
                                                 FROM LIMPRODAF, PRODUTO PR
                                                 WHERE PR.CDPRODUTO = LIMPRODAF.CDPRODUTO AND
                                                       LIMPRODAF.CDOPERADOR = V_CDCOMPRADOR AND
                                                       INSTR(PRODUTO.CDARVPROD, PR.CDARVPROD)= 1) AND
                                SOMAAF > LIMPRODAF.VRLIMPRODAF;
                          IF V_COUNT_LIMITE > 0 THEN
                             UPDATE AUTOFORNE
                                SET IDAFFORALIM = 'S', IDAUXIMPPORTAL = 'S', USR_DTEXPORTA = NULL
                              WHERE AUTOFORNE.CDFILDEST  = C_AUTOFORNE.CDFILDEST
                                AND AUTOFORNE.CDFILLANC  = NVL(C_AUTOFORNE.CDFILLANC, V_CDFILLANC)
                                AND AUTOFORNE.NRAUTOFORN = NVL(C_AUTOFORNE.NRAUTOFORN, V_PRXAUTOFORNE);
                          ELSE
                             SELECT COUNT(1)
                               INTO V_COUNT_LIMITE
                             FROM LIMPRODAF, AUTOFORNE, PRODUTO, PRODUTO P,
                              ( (SELECT
                                   PRODUTO,
                                   SUM(VRPRODUTO)  -
                                   NVL(SUM(VRDESCONTO), 0) +
                                   NVL(SUM(VRIMPOSTO), 0) AS SOMAAF
                                 FROM
                                   (
                                   SELECT
                                      SUM(ITEMAUTF.QTPROGENTAF * ITEMAUTF.VRPREUNIAF) AS VRPRODUTO,
                                      SUM((ITEMAUTF.QTPROGENTAF * ITEMAUTF.VRPREUNIAF *
                                           ITEMAUTF.VRPERDESAF) / 100)                AS VRDESCONTO,
                                      SUM(0) AS VRIMPOSTO, ITEMAUTF.CDPRODUTO AS PRODUTO
                                    FROM ITEMAUTF,
                                         AUTOFORNE
                                    WHERE
                                       AUTOFORNE.CDFILDEST  = ITEMAUTF.CDFILDEST AND
                                       AUTOFORNE.CDFILLANC  = ITEMAUTF.CDFILLANC AND
                                       AUTOFORNE.NRAUTOFORN = ITEMAUTF.NRAUTOFORN AND
                                       ITEMAUTF.CDPRODUTO   = C_ITEM_LIMITE.CDPRODUTO AND
                                       AUTOFORNE.DTMESAUTOFOR =
                                          (SELECT DTMESAUTOFOR
                                             FROM AUTOFORNE
                                            WHERE
                                               AUTOFORNE.CDFILDEST = C_AUTOFORNE.CDFILDEST AND
                                               AUTOFORNE.CDFILLANC = NVL(C_AUTOFORNE.CDFILLANC, V_CDFILLANC)AND
                                               AUTOFORNE.NRAUTOFORN= NVL(C_AUTOFORNE.NRAUTOFORN, V_PRXAUTOFORNE)) AND
                                       AUTOFORNE.CDFILDEST = C_AUTOFORNE.CDFILDEST AND
                                       AUTOFORNE.CDOPERADOR = V_CDCOMPRADOR
                                    GROUP BY ITEMAUTF.CDPRODUTO

                                   UNION

                                   SELECT
                                      SUM(0) AS VRPRODUTO,
                                      SUM(0) AS VRDESCONTO,
                                      SUM(IMPITMAF.VRADIMPAF) AS VRIMPOSTO,
                                      ITEMAUTF.CDPRODUTO AS PRODUTO
                                   FROM
                                      IMPITMAF,
                                      ITEMAUTF,
                                      AUTOFORNE
                                   WHERE
                                      IMPITMAF.CDFILDEST   = ITEMAUTF.CDFILDEST   AND
                                      IMPITMAF.CDFILLANC   = ITEMAUTF.CDFILLANC   AND
                                      IMPITMAF.NRAUTOFORN  = ITEMAUTF.NRAUTOFORN  AND
                                      IMPITMAF.CDPRODUTO   = ITEMAUTF.CDPRODUTO   AND
                                      IMPITMAF.CDMARCA     = ITEMAUTF.CDMARCA     AND
                                      IMPITMAF.DTPROGENTAF = ITEMAUTF.DTPROGENTAF AND
                                      AUTOFORNE.CDFILDEST  = ITEMAUTF.CDFILDEST    AND
                                      AUTOFORNE.CDFILLANC  = ITEMAUTF.CDFILLANC    AND
                                      AUTOFORNE.NRAUTOFORN = ITEMAUTF.NRAUTOFORN   AND
                                      ITEMAUTF.CDPRODUTO   = C_ITEM_LIMITE.CDPRODUTO AND
                                      AUTOFORNE.DTMESAUTOFOR =
                                         (SELECT DTMESAUTOFOR
                                            FROM AUTOFORNE
                                           WHERE
                                              AUTOFORNE.CDFILDEST = C_AUTOFORNE.CDFILDEST AND
                                              AUTOFORNE.CDFILLANC = NVL(C_AUTOFORNE.CDFILLANC, V_CDFILLANC) AND
                                              AUTOFORNE.NRAUTOFORN= NVL(C_AUTOFORNE.NRAUTOFORN, V_PRXAUTOFORNE)) AND
                                      AUTOFORNE.CDFILDEST = C_AUTOFORNE.CDFILDEST AND
                                      AUTOFORNE.CDOPERADOR = V_CDCOMPRADOR
                                   GROUP BY ITEMAUTF.CDPRODUTO
                                   )
                                   GROUP BY PRODUTO
                                   ))
                             WHERE  PRODUTO.CDPRODUTO = PRODUTO AND
                                   (AUTOFORNE.CDFILDEST = C_AUTOFORNE.CDFILDEST) AND
                                   (AUTOFORNE.CDFILLANC = NVL(C_AUTOFORNE.CDFILLANC, V_CDFILLANC)) AND
                                   (AUTOFORNE.NRAUTOFORN= NVL(C_AUTOFORNE.NRAUTOFORN, V_PRXAUTOFORNE)) AND
                                   (AUTOFORNE.CDOPERADOR= LIMPRODAF.CDOPERADOR) AND
                                   (P.CDPRODUTO = LIMPRODAF.CDPRODUTO) AND
                                   P.CDARVPROD =
                                                   (SELECT MAX(PR.CDARVPROD)
                                                    FROM LIMPRODAF, PRODUTO PR
                                                    WHERE PR.CDPRODUTO = LIMPRODAF.CDPRODUTO AND
                                                          LIMPRODAF.CDOPERADOR = V_CDCOMPRADOR AND
                                                          INSTR(PRODUTO.CDARVPROD, PR.CDARVPROD)= 1) AND
                                   SOMAAF > LIMPRODAF.VRLIMPRAFMES;
                             IF V_COUNT_LIMITE > 0 THEN
                                UPDATE AUTOFORNE
                                   SET IDAFFORALIM = 'S', IDAUXIMPPORTAL = 'S', USR_DTEXPORTA = NULL
                                 WHERE AUTOFORNE.CDFILDEST  = C_AUTOFORNE.CDFILDEST
                                   AND AUTOFORNE.CDFILLANC  = NVL(C_AUTOFORNE.CDFILLANC, V_CDFILLANC)
                                   AND AUTOFORNE.NRAUTOFORN = NVL(C_AUTOFORNE.NRAUTOFORN, V_PRXAUTOFORNE);
                             END IF;
                          END IF;
                       END LOOP;
                    END IF;
                 END IF;
                 IF NOT (V_COUNT_LIMITE > 0) THEN
                    UPDATE AUTOFORNE
                      SET IDAFFORALIM = 'N', IDBAIXAAF = NULL, USR_DTEXPORTA = NULL, IDAUXIMPPORTAL = 'S'
                    WHERE AUTOFORNE.CDFILDEST  = C_AUTOFORNE.CDFILDEST
                      AND AUTOFORNE.CDFILLANC  = NVL(C_AUTOFORNE.CDFILLANC, V_CDFILLANC)
                      AND AUTOFORNE.NRAUTOFORN = NVL(C_AUTOFORNE.NRAUTOFORN, V_PRXAUTOFORNE);
                 END IF;
               ELSE
                 UPDATE AUTOFORNE
                   SET IDAFFORALIM = 'N', IDBAIXAAF = NULL, USR_DTEXPORTA = NULL, IDAUXIMPPORTAL = 'S'
                 WHERE AUTOFORNE.CDFILDEST  = C_AUTOFORNE.CDFILDEST
                   AND AUTOFORNE.CDFILLANC  = NVL(C_AUTOFORNE.CDFILLANC, V_CDFILLANC)
                   AND AUTOFORNE.NRAUTOFORN = NVL(C_AUTOFORNE.NRAUTOFORN, V_PRXAUTOFORNE);
               END IF;
            ELSE
               IF C_AUTOFORNE.IDTPEXPITSOL = '2' THEN
                  UPDATE AUTOFORNE
                     SET IDBAIXAAF = '4', IDAUXIMPPORTAL = 'S'
                   WHERE AUTOFORNE.CDFILDEST  = C_AUTOFORNE.CDFILDEST
                     AND AUTOFORNE.CDFILLANC  = C_AUTOFORNE.CDFILLANC
                     AND AUTOFORNE.NRAUTOFORN = C_AUTOFORNE.NRAUTOFORN;
               END IF;
            END IF;
         END IF;
         UPDATE USR_INT_AUTOFORNE
            SET DTIMPORTACAO = TO_DATE(SYSDATE),
                HRIMPORTACAO = TO_CHAR(SYSDATE, 'HH24MI')
          WHERE NRSEQUENCIAL = C_AUTOFORNE.NRSEQUENCIAL;

         COMMIT;
      END LOOP;

      FOR C_AF_SEM_ITEM IN
         (SELECT ROWID
            FROM AUTOFORNE
           WHERE NOT EXISTS (SELECT 1
                               FROM ITEMAUTF
                              WHERE ITEMAUTF.CDFILDEST  = AUTOFORNE.CDFILDEST
                                AND ITEMAUTF.CDFILLANC  = AUTOFORNE.CDFILLANC
                                AND ITEMAUTF.NRAUTOFORN = AUTOFORNE.NRAUTOFORN
                                AND NVL(ITEMAUTF.IDBAIXITMAF, '0') <> '3'))
      LOOP
         UPDATE AUTOFORNE
            SET IDBAIXAAF = '4', IDAFFORALIM = 'N'
          WHERE ROWID = C_AF_SEM_ITEM.ROWID;

         IF V_QTDE_COMMIT >= V_TOTAL_COMMIT THEN
            COMMIT;
            V_QTDE_COMMIT := 0;
         ELSE
            V_QTDE_COMMIT := V_QTDE_COMMIT + 1;
         END IF;
      END LOOP;
      COMMIT;
      V_RETURN := USR_FUNC_BLOQUEIO('USR_INT_AUTOFORNE%USR_INT_ITEMAUTF', 'D');
   END IF;
EXCEPTION
  WHEN OTHERS THEN BEGIN
     IF V_RETURN = 'S' THEN
        V_ERROR:= SQLERRM(SQLCODE);
        V_RETURN := USR_FUNC_BLOQUEIO('USR_INT_AUTOFORNE%USR_INT_ITEMAUTF', 'D', V_ERROR);
     END IF;
  END;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('USR_IMPORTA_AF','5.45.xxx'); END;
/
